@@ -3,7 +3,7 @@
 #' calculate an affine transformation matrix
 #' @param x fix landmarks
 #' @param y moving landmarks
-#' @param type set type of affine transformation: options are "affine", "rigid" and "similarity" (rigid + scale)
+#' @param type set type of affine transformation: options are  "rigid", "similarity" (rigid + scale) and "affine",
 #' @param reflection logical: if TRUE "rigid" and "similarity" allow reflections.
 #' @return returns a 4x4 (3x3 in 2D case)  transformation matrix
 #' 
@@ -12,7 +12,7 @@
 #' trafo <- computeTransform(boneLM[,,1],boneLM[,,2])
 #' transLM <- applyTransform(boneLM[,,2],trafo)
 #' @export
-computeTransform <- function(x,y,type=c("affine","rigid","similarity"),reflection=FALSE) {
+computeTransform <- function(x,y,type=c("rigid","similarity","affine"),reflection=FALSE) {
     type <- substr(type[1],1L,1L)
     if (type %in% c("r","s")) {
         scale <- TRUE
