@@ -31,8 +31,11 @@ applyTransform.mesh3d <- function(x,trafo,inverse=FALSE) {
      if (inverse)
          trafo <- solve(trafo)
      x$vb <- trafo%*%x$vb
-     if (!is.null(x$normals))
-         x <- vcgUpdateNormals(x)
+    if (det(trafo) < 0) {
+        x <- invertFaces(x)
+        message("reflection involved, faces orientation has been inverted")
+    } else if (!is.null(x$normals))
+        x <- vcgUpdateNormals(x)
      return(x)
  }
 
