@@ -75,7 +75,7 @@ relWarps <- function(data,scale=TRUE,CSinit=TRUE,alpha=1,tol=1e-10,orp=TRUE)
         proc$rotated <- orp(proc$rotated, mshape=proc$mshape)
     
 ### create bending energy matrix ###
-    BE <- CreateL(proc$mshape, blockdiag=FALSE)$Lsubk
+    BE <- CreateL(proc$mshape,output="Lsubk")$Lsubk
 ### vectorize and scale superimposed data ###
     vecs <- vecx(proc$rotated)
     vecs <- apply(vecs,2,scale,scale=F)
