@@ -11,13 +11,13 @@
 #' dimnames[[3]] vector contains the names of the surface model (without file
 #' extension) - e.g. if the model is named "surface.ply", the name of the
 #' corresponding matrix of the array would be "surface"
-#' @param SMvector A vector containing the landmarks on the curve(s) and
+#' @param SMvector A vector containing the row indices of (semi-) landmarks on the curve(s) and
 #' surfaces that are allowed to slide
 #' @param outlines A vector (or if threre are several curves) a list of vectors
 #' (containing the rowindices) of the (Semi-)landmarks forming the curve(s) in
 #' the successive position on the curve - including the beginning and end
 #' points, that are not allowed to slide.
-#' @param surp A vector containing Semilandmarks positioned on surfaces.
+#' @param surp integer vector containing the row indices of semi-landmarks positioned on surfaces.
 #' @param sur.path Path to the surface models (e.g. ply, obj, stl files)
 #' @param sur.name character vector: containing the filenames of the
 #' corresponding surfaces - e.g. if the dat.array[,,i] belongs to
@@ -35,9 +35,8 @@
 #' landmarks, that are not allowed to slide.
 #' @param inc.check Logical: if TRUE, the program stops when convergence
 #' criterion starts increasing and reports result from last iteration.
-#' @param speed Logical: if TRUE, only a partial procrustes fit will be
-#' performed - this is faster and can be required, when large samples are
-#' processed.
+#' @param fullGPA Logical: if FALSE, only a partial procrustes fit will be
+#' performed.
 #' @param recursive Logical: if TRUE, during the iterations of the sliding
 #' process, the outcome of the previous iteration will be used.  Otherwise the
 #' original configuration will be used in all iterations.
@@ -50,9 +49,11 @@
 #' landmarks, while the right side contains the corresponding right hand
 #' landmarks. - This will ideally create symmetric mean to get rid of
 #' assymetry.
-#' @param weights vector: assign a weight to each landmark: the smaller the
-#' value is, the less it will be affected by sliding. 0 = fix. This is highly
-#' experimental!!!
+#' @param bending if TRUE, bending energy will be minimized, Procrustes distance otherwise.
+#' @param stepsize integer: dampening factor for the amount of sliding.
+#' Useful to keep semi-landmarks from sliding too far off the surface.
+#' The displacement is calculated as  \eqn{\Upsilon = \Upsilon^0 + stepsize * UT}{Y = Y0 + stepsize * UT}.
+#' Default is set to 1 for bending=TRUE and 0.5 for bending=FALSE.
 #' @param mc.cores integer: determines how many cores to use for the
 #' computation. The default is autodetect. But in case, it doesn't work as
 #' expected cores can be set manually. In Windows, parallel processing is
@@ -60,6 +61,7 @@
 #' @param fixRepro logical: if \code{TRUE}, fix landmarks will also be
 #' projected onto the surface. If you have landmarks not on the surface, select
 #' \code{fixRepro=FALSE}
+#' @param missingList a list of length samplesize containing integer vectors of row indices specifying missing landmars for each specimen. For specimens without missing landmarks enter \code{numeric(0)}.
 #' @return
 #' \item{dataslide }{array containing slidden Landmarks in the original
 #' space - not yet processed by a Procrustes analysis}
@@ -72,7 +74,7 @@
 #' and system resource usage. You can easily stall you computer with this
 #' function with inappropriate data.
 #' @author Stefan Schlager
-#' @seealso \code{\link{relaxLM}}
+#' @seealso \code{\link{relaxLM}, \link{createMissingList}}
 #' @encoding utf8
 #' @references Klingenberg CP, Barluenga M, and Meyer A. 2002. Shape analysis
 #' of symmetric structures: quantifying variation among individuals and
@@ -114,23 +116,30 @@
 #'                   # sur.path="." is the current working directory
 #' 
 #' # now one example with meshes in workspace
-#' ## to reduce this example's computation time,
-#' # we only use the first 50 right hand semi-landmarks
-#' surp <- surp[1:50]
+#' 
 #' meshlist <- meshlist <- list(shortnose.mesh,longnose.mesh)
 #' 
-#' slide <- slider3d(data[1:57,,], SMvector=fix, deselect=TRUE, surp=surp,
-#'                   sur.path=".",iterations=1, meshlist=meshlist,
+#' slide <- slider3d(data, SMvector=fix, deselect=TRUE, surp=surp,
+#'                   iterations=1, meshlist=meshlist,
 #'                   mc.cores=1,fixRepro=FALSE)
 #' require(rgl)
 #' ## visualize sliding
 #' deformGrid3d(slide$dataslide[,,1],shortnose.lm,ngrid = 0)
 #' ## these are fix
 #' spheres3d(slide$dataslide[fix,,1],col=4,radius=0.7)
+#'
+#' ###finally an example with missing landmarks:
+#' ## we assume that coordinates 185:189, 205:209 and 225:229 are in the second config are missing
+#' missingList <- createMissingList(2)
+#' missingList[[2]] <- c(185:189,205:209,225:229)
+#' slideMissing <- slider3d(data, SMvector=fix, deselect=TRUE, surp=surp,
+#'                   iterations=1, meshlist=meshlist,
+#'                   mc.cores=1,fixRepro=FALSE,missingList=missingList)
+#' 
 #' }
 #' 
 #' @export
-slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",sur.name=NULL, meshlist=NULL, ignore=NULL,sur.type="ply",tol=1e-05,deselect=FALSE,inc.check=TRUE,recursive=TRUE,iterations=0,initproc=TRUE,speed=TRUE,pairedLM=0,weights=NULL,mc.cores = parallel::detectCores(), fixRepro=TRUE)
+slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",sur.name=NULL, meshlist=NULL, ignore=NULL,sur.type="ply",tol=1e-05,deselect=FALSE,inc.check=TRUE,recursive=TRUE,iterations=0,initproc=TRUE,fullGPA=FALSE,pairedLM=0,bending=TRUE,stepsize=ifelse(bending,1,0.5),mc.cores = parallel::detectCores(), fixRepro=TRUE,missingList=NULL)
 {
     if(.Platform$OS.type == "windows")
         mc.cores <- 1
@@ -141,20 +150,15 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
     if (is.null(outlines) && is.null(surp))	
         stop("nothing to slide")
     
-    if (speed) {
-        scale <- FALSE
-        CSinit <- TRUE
-    } else {
-        scale <- TRUE
-        CSinit <- FALSE
-    }
     n <- dim(dat.array)[3]
     k <- dim(dat.array)[1]
     m <- dim(dat.array)[2]
     
     if (pairedLM[1]!=0 && is.vector(pairedLM))# check if there are only 2 symmetric lms
         pairedLM <- t(as.matrix(pairedLM))
-    
+    if(!is.null(missingList))
+        if(length(missingList) != n)
+            stop(paste0("missingList must be of length", n," - same as samplesize"))
 ### update indexing for after ignored landmarks are removed ###	
     if (!is.null(ignore)) {
         li <- length(ignore)
@@ -168,7 +172,8 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
                     xo[which(xo==mat.ptr[i,2])] <- mat.ptr[i,1]
                 return(xo)
             }
-        
+        if (!is.null(missingList))
+            missingList <- lapply(missingList,ptr)
         if (!is.null(outlines)) ### update outline indices
             outlines <- lapply(outlines,ptr)
         if (!is.null(surp)) 	### update surface indices
@@ -231,9 +236,15 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
     }
     parfunmeshfile <- function(i, data) {
         if (!is.list(data))
-            out <- projRead(data[,,i],sur.name[i])
+            tmpdata <- data[,,i]
         else
-            out <- projRead(data[[i]],sur.name[i])
+            tmpdata <- data[[i]]
+        
+        out <- projRead(tmpdata,sur.name[i])
+        if (!is.null(missingList))
+            if(length(missingList[[i]]))
+                out$vb[1:3,missingList[[i]]] <- t(tmpdata[missingList[[i]],])
+        
         return(out)
 
     }
@@ -257,7 +268,7 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
     
     if (initproc==TRUE) { # perform proc fit before sliding
         cat("Inital procrustes fit ...")	
-        procini <- ProcGPA(dat.array,scale=scale,CSinit=CSinit)
+        procini <- ProcGPA(dat.array,scale=fullGPA)
         mshape <- procini$mshape
     }
     dataslide <- dat.array
@@ -280,13 +291,31 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
         cat(paste("Iteration",count,sep=" "),"..\n")  # reports which Iteration is calculated
         if (recursive==TRUE)    # slided Semilandmarks are used in next iteration step
             dat.array <- dataslide
-        
-        L <- CreateL(mshape)
+        if (bending)
+            L <- CreateL(mshape,output="Lsubk3")
+        else
+            fixRepro=TRUE
         a.list <- as.list(1:n)
         slido <- function(j)          		
             {
-                U <- .calcTang_U_s(dat.array[,,j],vn.array[,,j],SMvector=SMvector,outlines=outlines,surface=surp,deselect=deselect,weights=weights)
-                dataslido <- calcGamma(U$Gamma0,L$Lsubk3,U$U,dims=m)$Gamatrix
+                free <- NULL
+                if (!is.null(missingList))
+                    if(length(missingList[[j]]))
+                        free <- missingList[[j]]
+                tmpdata <- dat.array[,,j]
+                tmpvn <- vn.array[,,j]
+                if (!bending) {
+                    rot <- rotonto(mshape,tmpdata,reflection=FALSE,scale=TRUE)
+                    tmpdata <- rot$yrot
+                    tmpvn <- tmpvn%*%rot$gamm
+                }
+                U <- .calcTang_U_s(tmpdata,tmpvn,SMvector=SMvector,outlines=outlines,surface=surp,deselect=deselect,free=free)
+                if (bending) {
+                    dataslido <- calcGamma(U$Gamma0,L$Lsubk3,U$U,dims=m,stepsize=stepsize)
+                } else {
+                    dataslido <- calcProcDGamma(U$U,U$Gamma0,mshape,dims=m,stepsize=stepsize)
+                    dataslido <- rotreverse(dataslido,rot)
+                }
                 return(dataslido)
             }
         a.list <- mclapply(a.list,slido,mc.cores=mc.cores)
@@ -307,7 +336,7 @@ slider3d <- function(dat.array,SMvector,outlines=NULL,surp=NULL,sur.path="sur",s
             dataslide[fixLM,,] <- data.orig[fixLM,,]
         
         cat("estimating sample mean shape...")          	
-        proc <- ProcGPA(dataslide,scale=scale,CSinit=CSinit)
+        proc <- ProcGPA(dataslide,scale=fullGPA)
         mshape <- proc$mshape
         if (pairedLM[1]!=0) {# create symmetric mean to get rid of assymetry along outline after first relaxation
             Mir <- diag(c(-1,1,1))
